searchData={"items":[{"type":"module","doc":"[App Store Server API](https://developer.apple.com/documentation/appstoreserverapi) client.","title":"AppStore","ref":"AppStore.html"},{"type":"function","doc":"Build the `AppStore` struct.","title":"AppStore.build/1","ref":"AppStore.html#build/1"},{"type":"function","doc":"- `api`: Optional, a keyword list to concsturct a `AppStore.API.Config`.\n  - `server_url`: Optional, the API server URL, default to the value of `AppStore.API.Config.production_server_url/0`\n  - `http_client`: Optional, the module used to make HTTP calls, default to `AppStore.HTTPClient.DefaultClient`\n  - `json_coder`: Optional, the module used as JSON encoder & decoder, default to `AppStore.JSON.DefaultCoder`\n- `token`: Optional, a keyword list to options to construct a `AppStore.Token.Config`.\n  - `json_coder`: Optional, the module used as JSON encoder & decoder, default to `AppStore.JSON.DefaultCoder`","title":"Options - AppStore.build/1","ref":"AppStore.html#build/1-options"},{"type":"function","doc":"iex> AppStore.build()\n    %AppStore{\n      api_config: %AppStore.API.Config{\n        http_client: AppStore.HTTPClient.DefaultClient,\n        json_coder: AppStore.JSON.DefaultCoder,\n        server_url: \"https://api.storekit.itunes.apple.com\"\n      },\n      token_config: %AppStore.Token.Config{\n        json_coder: AppStore.JSON.DefaultCoder\n      }\n    }\n\n    iex> AppStore.build([\n      api: [\n        http_client: YourHTTPClient,\n        json_coder: YourJSONCoder,\n        server_url: \"https://api.storekit.itunes.apple.com\"\n      ],\n      token: [\n        json_coder: YourJSONCoder\n      ]\n    ])\n    %AppStore{\n      api_config: %AppStore.API.Config{\n        http_client: YourHTTPClient,\n        json_coder: YourJSONCoder,\n        server_url: \"https://api.storekit.itunes.apple.com\"\n      },\n      token_config: %AppStore.Token.Config{\n        json_coder: YourJSONCoder\n      }\n    }","title":"Example - AppStore.build/1","ref":"AppStore.html#build/1-example"},{"type":"function","doc":"Get current app version","title":"AppStore.version/0","ref":"AppStore.html#version/0"},{"type":"type","doc":"","title":"AppStore.t/0","ref":"AppStore.html#t:t/0"},{"type":"module","doc":"A module to validate the JWS from Apple.","title":"AppStore.JWSValidation","ref":"AppStore.JWSValidation.html"},{"type":"function","doc":"","title":"AppStore.JWSValidation.get_binary_cert_chain/1","ref":"AppStore.JWSValidation.html#get_binary_cert_chain/1"},{"type":"function","doc":"Validate the signed payload from Apple.\n\nOfficial documentation: [JWS Transaction\n](https://developer.apple.com/documentation/appstoreserverapi/jwstransaction)","title":"AppStore.JWSValidation.validate/1","ref":"AppStore.JWSValidation.html#validate/1"},{"type":"function","doc":"iex> AppStore.JWSValidation.validate(\"\n      eyJhbGciOiJFUzI1NiIsImtpZCI6IjJYOVI0SFhGMzQiLCJ0eXAiOiJKV1QifQ.eyJhdWQiOiJhcHBzdG9yZWNvbm5lY3QtdjEiLCJiaWQiOiJjb20uZXhhbXBsZS50ZXN0YnVuZGxlaWQyMDIxIiwiZXhwIjoxNjI5NTA2MjQwLCJpYXQiOjE2Mjk1MDI3MDAsImlzcyI6IjU3MjQ2NTQyLTk2ZmUtMWE2My1lMDUzLTA4MjRkMDExMDcyYSIsIm5vbmNlIjoiMnFlaWc0a2wxOTQ0aHFhbmVzMDAwMGMxIn0.gYa_A7J6a6UAyBTAohf4gj28jT0k-OX1CW8cwsVGb4EewEm3owdsv6iWvzt7SutCndCBg5hPfNFWuZ0Au20HxA\"\n    )\n    {:ok,\n     %JOSE.JWT{\n       fields: %{\n         \"bundleId\" => \"com.example\",\n         \"environment\" => \"Sandbox\",\n         \"signedDate\" => 1_672_956_154_000\n       }\n     }}\n\n    iex> AppStore.JWSValidation.validate([\"signed_payload1\", \"signed_payload2\"]))\n    [\n      {:ok, %JOSE.JWT{fields: %{\"bundleId\" => \"com.example\", \"environment\" => \"Sandbox\", \"signedDate\" => 1_672_956_154_000}}},\n      {:ok, %JOSE.JWT{fields: %{\"bundleId\" => \"com.example2\", \"environment\" => \"Sandbox\", \"signedDate\" => 1_672_956_154_000}}}\n    ]","title":"Examples - AppStore.JWSValidation.validate/1","ref":"AppStore.JWSValidation.html#validate/1-examples"},{"type":"function","doc":"","title":"AppStore.JWSValidation.validate_certificate_chain/2","ref":"AppStore.JWSValidation.html#validate_certificate_chain/2"},{"type":"module","doc":"A module to generate the signed token for API usage.\n\nPlease also check `AppStore.Token.Server` for a `GenServer` to cache","title":"AppStore.Token","ref":"AppStore.Token.html"},{"type":"function","doc":"Generate the token for API Requests\n\nOfficial documentation: [Generating Tokens for API Requests\n](https://developer.apple.com/documentation/appstoreserverapi/generating_tokens_for_api_requests)","title":"AppStore.Token.generate_token/3","ref":"AppStore.Token.html#generate_token/3"},{"type":"function","doc":"- `issuer_id`: Your issuer ID from the Keys page in App Store Connect\n- `bundle_id`: Your app’s bundle ID\n- `key`: a map with the Key ID and Private key\n  - `id`: Your private key ID from App Store Connect\n  - `pem`: Your private API key generated from App Store Connect, please check [Creating API Keys to Use With the App Store Server API\n](https://developer.apple.com/documentation/appstoreserverapi/creating_api_keys_to_use_with_the_app_store_server_api)","title":"Options - AppStore.Token.generate_token/3","ref":"AppStore.Token.html#generate_token/3-options"},{"type":"function","doc":"iex> AppStore.Token.generate_token(\n      \"57246542-96fe-1a63-e053-0824d011072a\",\n      \"com.example.testbundleid2021\",\n      %{\n        id: \"2X9R4HXF34\",\n        pem: \"-----BEGIN PRIVATE KEY----- ...\"\n      }\n    )\n    \"eyJhbGciOiJFUzI1NiIsImtpZCI6IjJYOVI0SFhGMzQiLCJ0eXAiOiJKV1QifQ.eyJhdWQiOiJhcHBzdG9yZWNvbm5lY3QtdjEiLCJiaWQiOiJjb20uZXhhbXBsZS50ZXN0YnVuZGxlaWQyMDIxIiwiZXhwIjoxNjI5NTA2MjQwLCJpYXQiOjE2Mjk1MDI3MDAsImlzcyI6IjU3MjQ2NTQyLTk2ZmUtMWE2My1lMDUzLTA4MjRkMDExMDcyYSIsIm5vbmNlIjoiMnFlaWc0a2wxOTQ0aHFhbmVzMDAwMGMxIn0.gYa_A7J6a6UAyBTAohf4gj28jT0k-OX1CW8cwsVGb4EewEm3owdsv6iWvzt7SutCndCBg5hPfNFWuZ0Au20HxA\"","title":"Example - AppStore.Token.generate_token/3","ref":"AppStore.Token.html#generate_token/3-example"},{"type":"type","doc":"","title":"AppStore.Token.key/0","ref":"AppStore.Token.html#t:key/0"},{"type":"module","doc":"","title":"AppStore.Token.Config","ref":"AppStore.Token.Config.html"},{"type":"function","doc":"Build the AppStore client, used by functions in module `AppStore.API`","title":"AppStore.Token.Config.build/1","ref":"AppStore.Token.Config.html#build/1"},{"type":"function","doc":"- `json_coder`: Optional, the module used as JSON encoder & decoder, default to `AppStore.JSON.DefaultCoder`","title":"Options - AppStore.Token.Config.build/1","ref":"AppStore.Token.Config.html#build/1-options"},{"type":"type","doc":"","title":"AppStore.Token.Config.t/0","ref":"AppStore.Token.Config.html#t:t/0"},{"type":"module","doc":"A server for `AppStore.Token`, generate and cache token.","title":"AppStore.Token.Server","ref":"AppStore.Token.Server.html"},{"type":"module","doc":"iex> AppStore.Token.Server.start_link(%{\n      issuer_id: \"57246542-96fe-1a63-e053-0824d011072a\",\n      bundle_id: \"com.example.testbundleid2021\",\n      key: %{\n        id: \"2X9R4HXF34\",\n        pem: \"-----BEGIN PRIVATE KEY----- ... -----END PRIVATE KEY-----\"\n      }\n    })\n    {:ok, server}\n\n    iex> AppStore.Token.Server.generate(server)\n    {:ok, \"token\", %{\n      ...claims\n    }}","title":"Usage - AppStore.Token.Server","ref":"AppStore.Token.Server.html#module-usage"},{"type":"function","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","title":"AppStore.Token.Server.child_spec/1","ref":"AppStore.Token.Server.html#child_spec/1"},{"type":"function","doc":"Generate a signed token and cache it for 59 minutes\nper the suggestion on Apple's documentation: [Generating Tokens for API Requests](https://developer.apple.com/documentation/appstoreserverapi/generating_tokens_for_api_requests)","title":"AppStore.Token.Server.generate/1","ref":"AppStore.Token.Server.html#generate/1"},{"type":"function","doc":"iex> AppStore.Token.Server.generate(server)\n    {:ok,\n      \"eyJhbGciOiJFUzI1NiIsImtpZCI6IjJYOVI0SFhGMzQiLCJ0eXAiOiJKV1QifQ.eyJhdWQiOiJhcHBzdG9yZWNvbm5lY3QtdjEiLCJiaWQiOiJjb20uZXhhbXBsZS50ZXN0YnVuZGxlaWQyMDIxIiwiZXhwIjoxNjI5NzI1MDYwLCJpYXQiOjE2Mjk3MjE1MjAsImlzcyI6IjU3MjQ2NTQyLTk2ZmUtMWE2My1lMDUzLTA4MjRkMDExMDcyYSIsIm5vbmNlIjoiMnFldXU1bGg4cTlqZzhkaXBnMDAwMDAyIn0.p4-aBtXXQh3QUz1Ok2dpyuWkUiuk2BI9UCIB6AFs8M0eDyrVnEAPkIydVd_CKMN-VeMrsbL06mG6uW_kCx0TaQ\",\n      %{\n        \"aud\" => \"appstoreconnect-v1\",\n        \"bid\" => \"com.example.testbundleid2021\",\n        \"exp\" => 1629725060,\n        \"iat\" => 1629721520,\n        \"iss\" => \"57246542-96fe-1a63-e053-0824d011072a\",\n        \"nonce\" => \"2qeuu5lh8q9jg8dipg000002\"\n      }\n    }","title":"Example - AppStore.Token.Server.generate/1","ref":"AppStore.Token.Server.html#generate/1-example"},{"type":"function","doc":"Start the server.","title":"AppStore.Token.Server.start_link/1","ref":"AppStore.Token.Server.html#start_link/1"},{"type":"function","doc":"iex> AppStore.Token.Server.start_link(%{\n      issuer_id: \"57246542-96fe-1a63-e053-0824d011072a\",\n      bundle_id: \"com.example.testbundleid2021\",\n      key: %{\n        id: \"2X9R4HXF34\",\n        pem: \"-----BEGIN PRIVATE KEY----- ... -----END PRIVATE KEY-----\"\n      }\n    })\n    {:ok, #PID<0.328.0>}","title":"Example - AppStore.Token.Server.start_link/1","ref":"AppStore.Token.Server.html#start_link/1-example"},{"type":"module","doc":"The state for `AppStore.Token.Server`.","title":"AppStore.Token.Server.State","ref":"AppStore.Token.Server.State.html"},{"type":"type","doc":"","title":"AppStore.Token.Server.State.config/0","ref":"AppStore.Token.Server.State.html#t:config/0"},{"type":"type","doc":"","title":"AppStore.Token.Server.State.t/0","ref":"AppStore.Token.Server.State.html#t:t/0"},{"type":"type","doc":"","title":"AppStore.Token.Server.State.token_info/0","ref":"AppStore.Token.Server.State.html#t:token_info/0"},{"type":"module","doc":"The main module to interact with the App Store Server APIs","title":"AppStore.API","ref":"AppStore.API.html"},{"type":"function","doc":"","title":"AppStore.API.get_subscription_statuses/3","ref":"AppStore.API.html#get_subscription_statuses/3"},{"type":"function","doc":"","title":"AppStore.API.get_transaction_history/4","ref":"AppStore.API.html#get_transaction_history/4"},{"type":"function","doc":"","title":"AppStore.API.get_transaction_info/3","ref":"AppStore.API.html#get_transaction_info/3"},{"type":"function","doc":"","title":"AppStore.API.send_consumption_information/4","ref":"AppStore.API.html#send_consumption_information/4"},{"type":"module","doc":"","title":"AppStore.API.Config","ref":"AppStore.API.Config.html"},{"type":"function","doc":"Build the AppStore client, used by functions in module `AppStore.API`","title":"AppStore.API.Config.build/1","ref":"AppStore.API.Config.html#build/1"},{"type":"function","doc":"- `server_url`: Optional, the API server URL, default to the value of `AppStore.API.Config.production_server_url/0`\n- `http_client`: Optional, the module used to make HTTP calls, default to `AppStore.HTTPClient.DefaultClient`\n- `json_coder`: Optional, the module used as JSON encoder & decoder, default to `AppStore.JSON.DefaultCoder`","title":"Options - AppStore.API.Config.build/1","ref":"AppStore.API.Config.html#build/1-options"},{"type":"function","doc":"Returns the production API server URL: https://api.storekit.itunes.apple.com","title":"AppStore.API.Config.production_server_url/0","ref":"AppStore.API.Config.html#production_server_url/0"},{"type":"function","doc":"Returns the sandbox API server URL: https://api.storekit-sandbox.itunes.apple.com","title":"AppStore.API.Config.sandbox_server_url/0","ref":"AppStore.API.Config.html#sandbox_server_url/0"},{"type":"type","doc":"","title":"AppStore.API.Config.t/0","ref":"AppStore.API.Config.html#t:t/0"},{"type":"module","doc":"The module for Consumption Information","title":"AppStore.API.ConsumptionInformation","ref":"AppStore.API.ConsumptionInformation.html"},{"type":"function","doc":"Send consumption information about a consumable in-app purchase to the App Store, after your server receives a consumption request notification.\n\nOfficial documentation: https://developer.apple.com/documentation/appstoreserverapi/send_consumption_information","title":"AppStore.API.ConsumptionInformation.send_consumption_information/4","ref":"AppStore.API.ConsumptionInformation.html#send_consumption_information/4"},{"type":"type","doc":"","title":"AppStore.API.ConsumptionInformation.original_transaction_id/0","ref":"AppStore.API.ConsumptionInformation.html#t:original_transaction_id/0"},{"type":"module","doc":"The struct representing the error from the API.","title":"AppStore.API.Error","ref":"AppStore.API.Error.html"},{"type":"type","doc":"","title":"AppStore.API.Error.client_error/0","ref":"AppStore.API.Error.html#t:client_error/0"},{"type":"type","doc":"","title":"AppStore.API.Error.server_error/0","ref":"AppStore.API.Error.html#t:server_error/0"},{"type":"type","doc":"","title":"AppStore.API.Error.t/0","ref":"AppStore.API.Error.html#t:t/0"},{"type":"module","doc":"The struct representing the response from API.","title":"AppStore.API.Response","ref":"AppStore.API.Response.html"},{"type":"type","doc":"","title":"AppStore.API.Response.t/0","ref":"AppStore.API.Response.html#t:t/0"},{"type":"module","doc":"The module for Subscription Status","title":"AppStore.API.SubscriptionStatus","ref":"AppStore.API.SubscriptionStatus.html"},{"type":"function","doc":"Get the statuses for all of a customer’s subscriptions in your app.\n\nOfficial documentation: https://developer.apple.com/documentation/appstoreserverapi/get_all_subscription_statuses","title":"AppStore.API.SubscriptionStatus.get_subscription_statuses/3","ref":"AppStore.API.SubscriptionStatus.html#get_subscription_statuses/3"},{"type":"type","doc":"","title":"AppStore.API.SubscriptionStatus.original_transaction_id/0","ref":"AppStore.API.SubscriptionStatus.html#t:original_transaction_id/0"},{"type":"module","doc":"The module for Transaction History","title":"AppStore.API.TransactionHistory","ref":"AppStore.API.TransactionHistory.html"},{"type":"function","doc":"Get a customer’s transaction history, including all of their in-app purchases in your app.\n\nOfficial documentation: https://developer.apple.com/documentation/appstoreserverapi/get_transaction_history","title":"AppStore.API.TransactionHistory.get_transaction_history/4","ref":"AppStore.API.TransactionHistory.html#get_transaction_history/4"},{"type":"type","doc":"","title":"AppStore.API.TransactionHistory.original_transaction_id/0","ref":"AppStore.API.TransactionHistory.html#t:original_transaction_id/0"},{"type":"type","doc":"","title":"AppStore.API.TransactionHistory.revision/0","ref":"AppStore.API.TransactionHistory.html#t:revision/0"},{"type":"module","doc":"The module for Transaction Info","title":"AppStore.API.TransactionInfo","ref":"AppStore.API.TransactionInfo.html"},{"type":"function","doc":"Get information about a single transaction for your app.\n\nOfficial documentation: https://developer.apple.com/documentation/appstoreserverapi/get_transaction_info","title":"AppStore.API.TransactionInfo.get_transaction_info/3","ref":"AppStore.API.TransactionInfo.html#get_transaction_info/3"},{"type":"type","doc":"","title":"AppStore.API.TransactionInfo.transaction_id/0","ref":"AppStore.API.TransactionInfo.html#t:transaction_id/0"},{"type":"behaviour","doc":"HTTPClient behaviour for AppStore","title":"AppStore.HTTPClient","ref":"AppStore.HTTPClient.html"},{"type":"behaviour","doc":"```elixir\ndefmodule MyApp.AwesomeHTTPClient do\n  @behaviour AppStore.HTTPClient\n\n  @impl true\n  def request(method, uri, body, headers \\ []) do\n    # request the server\n    if success\n      {:ok,\n      %{\n        status: response.status,\n        headers: response.headers,\n        body: response.body,\n        data: nil\n      }}\n    else\n      {:error, error} ->\n        {:error,\n          %{\n            code: :server_error,\n            detail: error\n          }\n        }\n    end\n  end\nend\n```\n\nThen Use the custom HTTP while building the client:\n\n```elixir\napp_store =\n  AppStore.build(\n    api: [\n      http_client: MyApp.AwesomeHTTPClient\n    ]\n  )\n```\n\nSee `AppStore.HTTPClient.DefaultClient` for a reference implementation.","title":"Build your own HTTP client: - AppStore.HTTPClient","ref":"AppStore.HTTPClient.html#module-build-your-own-http-client"},{"type":"function","doc":"","title":"AppStore.HTTPClient.perform_request/5","ref":"AppStore.HTTPClient.html#perform_request/5"},{"type":"callback","doc":"","title":"AppStore.HTTPClient.request/4","ref":"AppStore.HTTPClient.html#c:request/4"},{"type":"type","doc":"","title":"AppStore.HTTPClient.http_error/0","ref":"AppStore.HTTPClient.html#t:http_error/0"},{"type":"type","doc":"","title":"AppStore.HTTPClient.http_headers/0","ref":"AppStore.HTTPClient.html#t:http_headers/0"},{"type":"type","doc":"","title":"AppStore.HTTPClient.http_method/0","ref":"AppStore.HTTPClient.html#t:http_method/0"},{"type":"type","doc":"","title":"AppStore.HTTPClient.http_response/0","ref":"AppStore.HTTPClient.html#t:http_response/0"},{"type":"module","doc":"The default implementation for `AppStore.HTTPClient`. Uses `Finch` as the HTTP client.\n\nAdd the `AppStore.HTTPClient.DefaultClient` to your application's supervision tree:\n\n```elixir\n# lib/your_app/application.ex\ndef start(_type, _args) do\n  children = [\n    ...\n    {AppStore.HTTPClient.DefaultClient, []}\n  ]\n\n  ...\nend\n```\n\nOr start it dynamically with `start_link/1`","title":"AppStore.HTTPClient.DefaultClient","ref":"AppStore.HTTPClient.DefaultClient.html"},{"type":"function","doc":"Start an instance of the defalut HTTPClient.\n\nThe following options will be passed to the `Finch.start_link/1`:\n\n```elixir\n[\n  name: __MODULE__\n  pools: %{\n    AppStore.API.Config.sandbox_server_url() => [size: 1],\n    AppStore.API.Config.production_server_url() => [size: 10]\n  }\n]\n```\n\nYou override the default options with `opts`, see `Finch.start_link/1` for detail.","title":"AppStore.HTTPClient.DefaultClient.start_link/1","ref":"AppStore.HTTPClient.DefaultClient.html#start_link/1"},{"type":"function","doc":"```elixir\nopts = [\n  pools: %{\n    AppStore.API.Config.production_server_url() => [size: 30]\n  }\n]\n\nAppStore.HTTPClient.DefaultClient.start_link(opts)\n```","title":"Example - AppStore.HTTPClient.DefaultClient.start_link/1","ref":"AppStore.HTTPClient.DefaultClient.html#start_link/1-example"},{"type":"behaviour","doc":"JSON behaviour for AppStore","title":"AppStore.JSON","ref":"AppStore.JSON.html"},{"type":"behaviour","doc":"```elixir\ndefmodule MyApp.AwesomeJSONCoder do\n  @behaviour AppStore.JSON\n\n  @impl true\n  def decode!(json_string) do\n    Jason.decode!(json_string)\n  end\n\n  @impl true\n  def encode!(data) do\n    Jason.encode!(data)\n  end\nend\n```\n\nThen Use the custom JSON implementation while building the client:\n\n```elixir\nAppStore =\n  AppStore.build(\n    api: [\n      json_coder: MyApp.AwesomeJSONCoder\n    ],\n    token: [\n      json_coder: MyApp.AwesomeJSONCoder\n    ]\n  )\n```\n\nSee `AppStore.JSON.DefaultCoder` for a reference implementation.","title":"Build your own JSON encoder & decoder: - AppStore.JSON","ref":"AppStore.JSON.html#module-build-your-own-json-encoder-decoder"},{"type":"callback","doc":"","title":"AppStore.JSON.decode!/1","ref":"AppStore.JSON.html#c:decode!/1"},{"type":"callback","doc":"","title":"AppStore.JSON.encode!/1","ref":"AppStore.JSON.html#c:encode!/1"},{"type":"module","doc":"The default implementation for `AppStore.JSON`. Uses `Jason` as the JSON encoder & decoder.","title":"AppStore.JSON.DefaultCoder","ref":"AppStore.JSON.DefaultCoder.html"},{"type":"extras","doc":"# App Store\n\n[App Store Server API](https://developer.apple.com/documentation/appstoreserverapi) client.","title":"App Store","ref":"readme.html"},{"type":"extras","doc":"The package can be installed\nby adding `app_store` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:app_store, \"~> 0.2.1\"}\n  ]\nend\n```","title":"Installation - App Store","ref":"readme.html#installation"},{"type":"extras","doc":"Add the default HTTP client `AppStore.HTTPClient.DefaultClient` to the application's supervision tree:\n\n```elixir\n# lib/your_app/application.ex\ndef start(_type, _args) do\n  children = [\n    ...\n    {AppStore.HTTPClient.DefaultClient, []}\n  ]\n\n  ...\nend\n```\n\nBuild the client:\n\n```elixir\niex> app_store = AppStore.build()\n\n%AppStore{\n  api_config: %AppStore.API.Config{\n    http_client: AppStore.HTTPClient.DefaultClient,\n    json_coder: AppStore.JSON.DefaultCoder,\n    server_url: \"https://api.storekit.itunes.apple.com\"\n  },\n  token_config: %AppStore.Token.Config{\n    json_coder: AppStore.JSON.DefaultCoder\n  }\n}\n```\n\nGenerate a token:\n\n```elixir\niex> token = AppStore.Token.generate_token(\n  \"57246542-96fe-1a63-e053-0824d011072a\",\n  \"com.example.testbundleid2021\",\n  %{\n    id: \"2X9R4HXF34\",\n    pem: \"-----BEGIN PRIVATE KEY----- ...\"\n  }\n)\n\n\"eyJhbGciOiJFUzI1NiIsImtpZCI6IjJYOVI0SFhGMzQiLCJ0eXAiOiJKV1QifQ.eyJhdWQiOiJhcHBzdG9yZWNvbm5lY3QtdjEiLCJiaWQiOiJjb20uZXhhbXBsZS50ZXN0YnVuZGxlaWQyMDIxIiwiZXhwIjoxNjI5NTA2MjQwLCJpYXQiOjE2Mjk1MDI3MDAsImlzcyI6IjU3MjQ2NTQyLTk2ZmUtMWE2My1lMDUzLTA4MjRkMDExMDcyYSIsIm5vbmNlIjoiMnFlaWc0a2wxOTQ0aHFhbmVzMDAwMGMxIn0.gYa_A7J6a6UAyBTAohf4gj28jT0k-OX1CW8cwsVGb4EewEm3owdsv6iWvzt7SutCndCBg5hPfNFWuZ0Au20HxA\"\n```\n\nGet transactions history:\n\n```elixir\niex> {:ok, %AppStore.API.Response{body: %{\"signedTransactions\" => signed_transactions} = body, status: status}} =\n  AppStore.API.get_transaction_history(\n    app_store.api_config,\n    token,\n    \"the-transaction-id\"\n  )\n```\n\nValidate the response:\n\n```elixir\niex>  [\n        {:ok, %JOSE.JWT{fields: %{\"bundleId\" => \"com.example\", \"environment\" => \"Sandbox\", \"signedDate\" => 1_672_956_154_000}}},\n        {:ok, %JOSE.JWT{fields: %{\"bundleId\" => \"com.example2\", \"environment\" => \"Sandbox\", \"signedDate\" => 1_672_956_154_000}}}\n      ] = JWSValidation.validate(signed_transactions)\n```\n\nPlease check [https://hexdocs.pm/app_store](https://hexdocs.pm/app_store) for a full documentation.","title":"Usage - App Store","ref":"readme.html#usage"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,49]}}